"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Format:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Format.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FORMAT_UNSPECIFIED: _Format.ValueType  # 0
    VERSION_11: _Format.ValueType  # 1
    """A legacy backup format used in older versions. It's not recommended to use."""
    VERSION_12: _Format.ValueType  # 2
    """A new format recommended in most cases for fast backup and recovery."""
    AUTO: _Format.ValueType  # 3
    """Automatic version selection. Will be used version 12 unless the protection
    plan (policy) appends backups to the ones created by earlier product
    versions.
    """

class Format(_Format, metaclass=_FormatEnumTypeWrapper):
    """Format of the backup in policy. For backup locations that can be browsed
    with a file manager, the backup format determines the number of files and
    their extension.
    """

FORMAT_UNSPECIFIED: Format.ValueType  # 0
VERSION_11: Format.ValueType  # 1
"""A legacy backup format used in older versions. It's not recommended to use."""
VERSION_12: Format.ValueType  # 2
"""A new format recommended in most cases for fast backup and recovery."""
AUTO: Format.ValueType  # 3
"""Automatic version selection. Will be used version 12 unless the protection
plan (policy) appends backups to the ones created by earlier product
versions.
"""
global___Format = Format

@typing.final
class Policy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Policy ID."""
    name: builtins.str
    """Policy name."""
    enabled: builtins.bool
    """If this field is true, it means that the policy is enabled."""
    folder_id: builtins.str
    """ID of the folder that the policy belongs to."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def settings(self) -> global___PolicySettings:
        """Set of policy settings"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        enabled: builtins.bool = ...,
        settings: global___PolicySettings | None = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "settings", b"settings", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "enabled", b"enabled", "folder_id", b"folder_id", "id", b"id", "name", b"name", "settings", b"settings", "updated_at", b"updated_at"]) -> None: ...

global___Policy = Policy

@typing.final
class PolicySettings(google.protobuf.message.Message):
    """Set of policy settings"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Compression:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CompressionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicySettings._Compression.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        COMPRESSION_UNSPECIFIED: PolicySettings._Compression.ValueType  # 0
        NORMAL: PolicySettings._Compression.ValueType  # 1
        HIGH: PolicySettings._Compression.ValueType  # 2
        MAX: PolicySettings._Compression.ValueType  # 3
        OFF: PolicySettings._Compression.ValueType  # 4

    class Compression(_Compression, metaclass=_CompressionEnumTypeWrapper):
        """Compression rate of the backups."""

    COMPRESSION_UNSPECIFIED: PolicySettings.Compression.ValueType  # 0
    NORMAL: PolicySettings.Compression.ValueType  # 1
    HIGH: PolicySettings.Compression.ValueType  # 2
    MAX: PolicySettings.Compression.ValueType  # 3
    OFF: PolicySettings.Compression.ValueType  # 4

    class _RepeatePeriod:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RepeatePeriodEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicySettings._RepeatePeriod.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        REPEATE_PERIOD_UNSPECIFIED: PolicySettings._RepeatePeriod.ValueType  # 0
        HOURLY: PolicySettings._RepeatePeriod.ValueType  # 1
        DAILY: PolicySettings._RepeatePeriod.ValueType  # 2
        WEEKLY: PolicySettings._RepeatePeriod.ValueType  # 3
        MONTHLY: PolicySettings._RepeatePeriod.ValueType  # 4

    class RepeatePeriod(_RepeatePeriod, metaclass=_RepeatePeriodEnumTypeWrapper): ...
    REPEATE_PERIOD_UNSPECIFIED: PolicySettings.RepeatePeriod.ValueType  # 0
    HOURLY: PolicySettings.RepeatePeriod.ValueType  # 1
    DAILY: PolicySettings.RepeatePeriod.ValueType  # 2
    WEEKLY: PolicySettings.RepeatePeriod.ValueType  # 3
    MONTHLY: PolicySettings.RepeatePeriod.ValueType  # 4

    class _Day:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _DayEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicySettings._Day.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DAY_UNSPECIFIED: PolicySettings._Day.ValueType  # 0
        MONDAY: PolicySettings._Day.ValueType  # 1
        TUESDAY: PolicySettings._Day.ValueType  # 2
        WEDNESDAY: PolicySettings._Day.ValueType  # 3
        THURSDAY: PolicySettings._Day.ValueType  # 4
        FRIDAY: PolicySettings._Day.ValueType  # 5
        SATURDAY: PolicySettings._Day.ValueType  # 6
        SUNDAY: PolicySettings._Day.ValueType  # 7

    class Day(_Day, metaclass=_DayEnumTypeWrapper): ...
    DAY_UNSPECIFIED: PolicySettings.Day.ValueType  # 0
    MONDAY: PolicySettings.Day.ValueType  # 1
    TUESDAY: PolicySettings.Day.ValueType  # 2
    WEDNESDAY: PolicySettings.Day.ValueType  # 3
    THURSDAY: PolicySettings.Day.ValueType  # 4
    FRIDAY: PolicySettings.Day.ValueType  # 5
    SATURDAY: PolicySettings.Day.ValueType  # 6
    SUNDAY: PolicySettings.Day.ValueType  # 7

    class _ChangedBlockTracking:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ChangedBlockTrackingEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicySettings._ChangedBlockTracking.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CHANGED_BLOCK_TRACKING_UNSPECIFIED: PolicySettings._ChangedBlockTracking.ValueType  # 0
        USE_IF_ENABLED: PolicySettings._ChangedBlockTracking.ValueType  # 1
        ENABLE_AND_USE: PolicySettings._ChangedBlockTracking.ValueType  # 2
        DO_NOT_USE: PolicySettings._ChangedBlockTracking.ValueType  # 3

    class ChangedBlockTracking(_ChangedBlockTracking, metaclass=_ChangedBlockTrackingEnumTypeWrapper): ...
    CHANGED_BLOCK_TRACKING_UNSPECIFIED: PolicySettings.ChangedBlockTracking.ValueType  # 0
    USE_IF_ENABLED: PolicySettings.ChangedBlockTracking.ValueType  # 1
    ENABLE_AND_USE: PolicySettings.ChangedBlockTracking.ValueType  # 2
    DO_NOT_USE: PolicySettings.ChangedBlockTracking.ValueType  # 3

    class _CommandType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CommandTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicySettings._CommandType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        COMMAND_TYPE_UNSPECIFIED: PolicySettings._CommandType.ValueType  # 0
        PRE_COMMAND: PolicySettings._CommandType.ValueType  # 1
        """Launch command before backup execution"""
        POST_COMMAND: PolicySettings._CommandType.ValueType  # 2
        """Launch command after backup execution"""

    class CommandType(_CommandType, metaclass=_CommandTypeEnumTypeWrapper): ...
    COMMAND_TYPE_UNSPECIFIED: PolicySettings.CommandType.ValueType  # 0
    PRE_COMMAND: PolicySettings.CommandType.ValueType  # 1
    """Launch command before backup execution"""
    POST_COMMAND: PolicySettings.CommandType.ValueType  # 2
    """Launch command after backup execution"""

    @typing.final
    class Interval(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Type:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicySettings.Interval._Type.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            TYPE_UNSPECIFIED: PolicySettings.Interval._Type.ValueType  # 0
            SECONDS: PolicySettings.Interval._Type.ValueType  # 1
            MINUTES: PolicySettings.Interval._Type.ValueType  # 2
            HOURS: PolicySettings.Interval._Type.ValueType  # 3
            DAYS: PolicySettings.Interval._Type.ValueType  # 4
            WEEKS: PolicySettings.Interval._Type.ValueType  # 5
            MONTHS: PolicySettings.Interval._Type.ValueType  # 6

        class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
        TYPE_UNSPECIFIED: PolicySettings.Interval.Type.ValueType  # 0
        SECONDS: PolicySettings.Interval.Type.ValueType  # 1
        MINUTES: PolicySettings.Interval.Type.ValueType  # 2
        HOURS: PolicySettings.Interval.Type.ValueType  # 3
        DAYS: PolicySettings.Interval.Type.ValueType  # 4
        WEEKS: PolicySettings.Interval.Type.ValueType  # 5
        MONTHS: PolicySettings.Interval.Type.ValueType  # 6

        TYPE_FIELD_NUMBER: builtins.int
        COUNT_FIELD_NUMBER: builtins.int
        type: global___PolicySettings.Interval.Type.ValueType
        """A type of the interval."""
        count: builtins.int
        """The amount of value specified in `Interval.Type`."""
        def __init__(
            self,
            *,
            type: global___PolicySettings.Interval.Type.ValueType = ...,
            count: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["count", b"count", "type", b"type"]) -> None: ...

    @typing.final
    class RetriesConfiguration(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        INTERVAL_FIELD_NUMBER: builtins.int
        MAX_ATTEMPTS_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """If true, enables retry on errors."""
        max_attempts: builtins.int
        """Max number of retry attempts. Operation will be considered as failed 
        when max number of retry attempts is reached.
        """
        @property
        def interval(self) -> global___PolicySettings.Interval:
            """An interval between retry attempts."""

        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            interval: global___PolicySettings.Interval | None = ...,
            max_attempts: builtins.int = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["interval", b"interval"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "interval", b"interval", "max_attempts", b"max_attempts"]) -> None: ...

    @typing.final
    class Splitting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SIZE_FIELD_NUMBER: builtins.int
        size: builtins.int
        """The size of split backup file in bytes."""
        def __init__(
            self,
            *,
            size: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["size", b"size"]) -> None: ...

    @typing.final
    class VolumeShadowCopyServiceSettings(google.protobuf.message.Message):
        """Settings for Volume Shadow Copy Services which allows to notify
        VSS-aware applications that backup is about to start. This will
        ensure the consistent state of all data used by the applications.
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _VSSProvider:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _VSSProviderEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicySettings.VolumeShadowCopyServiceSettings._VSSProvider.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            VSS_PROVIDER_UNSPECIFIED: PolicySettings.VolumeShadowCopyServiceSettings._VSSProvider.ValueType  # 0
            NATIVE: PolicySettings.VolumeShadowCopyServiceSettings._VSSProvider.ValueType  # 1
            TARGET_SYSTEM_DEFINED: PolicySettings.VolumeShadowCopyServiceSettings._VSSProvider.ValueType  # 2

        class VSSProvider(_VSSProvider, metaclass=_VSSProviderEnumTypeWrapper): ...
        VSS_PROVIDER_UNSPECIFIED: PolicySettings.VolumeShadowCopyServiceSettings.VSSProvider.ValueType  # 0
        NATIVE: PolicySettings.VolumeShadowCopyServiceSettings.VSSProvider.ValueType  # 1
        TARGET_SYSTEM_DEFINED: PolicySettings.VolumeShadowCopyServiceSettings.VSSProvider.ValueType  # 2

        ENABLED_FIELD_NUMBER: builtins.int
        PROVIDER_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """If true, the VSS will be enabled."""
        provider: global___PolicySettings.VolumeShadowCopyServiceSettings.VSSProvider.ValueType
        """A type of VSS provider to use in backup."""
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            provider: global___PolicySettings.VolumeShadowCopyServiceSettings.VSSProvider.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "provider", b"provider"]) -> None: ...

    @typing.final
    class ArchiveProperties(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        name: builtins.str
        """The name of the generated archive. The name may use the following variables: `[Machine Name]`, `[Plan ID]`, `[Plan Name]`, `[Unique ID]`, `[Virtualization Server Type]`.
        Default value: `[Machine Name]-[Plan ID]-[Unique ID]A`.
        """
        def __init__(
            self,
            *,
            name: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

    @typing.final
    class PerformanceWindow(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """If true, the time windows will be enabled."""
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["enabled", b"enabled"]) -> None: ...

    @typing.final
    class TimeOfDay(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        HOUR_FIELD_NUMBER: builtins.int
        MINUTE_FIELD_NUMBER: builtins.int
        hour: builtins.int
        """Hours."""
        minute: builtins.int
        """Minutes."""
        def __init__(
            self,
            *,
            hour: builtins.int = ...,
            minute: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["hour", b"hour", "minute", b"minute"]) -> None: ...

    @typing.final
    class Retention(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class RetentionRule(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            BACKUP_SET_FIELD_NUMBER: builtins.int
            MAX_AGE_FIELD_NUMBER: builtins.int
            MAX_COUNT_FIELD_NUMBER: builtins.int
            max_count: builtins.int
            @property
            def backup_set(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___PolicySettings.RepeatePeriod.ValueType]:
                """A list of backup sets where rules are effective."""

            @property
            def max_age(self) -> global___PolicySettings.Interval: ...
            def __init__(
                self,
                *,
                backup_set: collections.abc.Iterable[global___PolicySettings.RepeatePeriod.ValueType] | None = ...,
                max_age: global___PolicySettings.Interval | None = ...,
                max_count: builtins.int = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["condition", b"condition", "max_age", b"max_age", "max_count", b"max_count"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["backup_set", b"backup_set", "condition", b"condition", "max_age", b"max_age", "max_count", b"max_count"]) -> None: ...
            def WhichOneof(self, oneof_group: typing.Literal["condition", b"condition"]) -> typing.Literal["max_age", "max_count"] | None: ...

        RULES_FIELD_NUMBER: builtins.int
        BEFORE_BACKUP_FIELD_NUMBER: builtins.int
        before_backup: builtins.bool
        """If true, retention rules will be applied before backup is finished."""
        @property
        def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PolicySettings.Retention.RetentionRule]:
            """A list of retention rules."""

        def __init__(
            self,
            *,
            rules: collections.abc.Iterable[global___PolicySettings.Retention.RetentionRule] | None = ...,
            before_backup: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["before_backup", b"before_backup", "rules", b"rules"]) -> None: ...

    @typing.final
    class Scheduling(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Scheme:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _SchemeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicySettings.Scheduling._Scheme.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            SCHEME_UNSPECIFIED: PolicySettings.Scheduling._Scheme.ValueType  # 0
            SIMPLE: PolicySettings.Scheduling._Scheme.ValueType  # 1
            ALWAYS_FULL: PolicySettings.Scheduling._Scheme.ValueType  # 2
            ALWAYS_INCREMENTAL: PolicySettings.Scheduling._Scheme.ValueType  # 3
            WEEKLY_INCREMENTAL: PolicySettings.Scheduling._Scheme.ValueType  # 4
            WEEKLY_FULL_DAILY_INCREMENTAL: PolicySettings.Scheduling._Scheme.ValueType  # 5
            CUSTOM: PolicySettings.Scheduling._Scheme.ValueType  # 6
            """Custom will require to specify schedules for full, differential
            and incremental backups additionally.
            """
            CDP: PolicySettings.Scheduling._Scheme.ValueType  # 7

        class Scheme(_Scheme, metaclass=_SchemeEnumTypeWrapper):
            """Scheme of backups."""

        SCHEME_UNSPECIFIED: PolicySettings.Scheduling.Scheme.ValueType  # 0
        SIMPLE: PolicySettings.Scheduling.Scheme.ValueType  # 1
        ALWAYS_FULL: PolicySettings.Scheduling.Scheme.ValueType  # 2
        ALWAYS_INCREMENTAL: PolicySettings.Scheduling.Scheme.ValueType  # 3
        WEEKLY_INCREMENTAL: PolicySettings.Scheduling.Scheme.ValueType  # 4
        WEEKLY_FULL_DAILY_INCREMENTAL: PolicySettings.Scheduling.Scheme.ValueType  # 5
        CUSTOM: PolicySettings.Scheduling.Scheme.ValueType  # 6
        """Custom will require to specify schedules for full, differential
        and incremental backups additionally.
        """
        CDP: PolicySettings.Scheduling.Scheme.ValueType  # 7

        @typing.final
        class BackupSet(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _Type:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicySettings.Scheduling.BackupSet._Type.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                TYPE_UNSPECIFIED: PolicySettings.Scheduling.BackupSet._Type.ValueType  # 0
                TYPE_AUTO: PolicySettings.Scheduling.BackupSet._Type.ValueType  # 1
                TYPE_FULL: PolicySettings.Scheduling.BackupSet._Type.ValueType  # 2
                TYPE_INCREMENTAL: PolicySettings.Scheduling.BackupSet._Type.ValueType  # 3
                TYPE_DIFFERENTIAL: PolicySettings.Scheduling.BackupSet._Type.ValueType  # 4

            class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
            TYPE_UNSPECIFIED: PolicySettings.Scheduling.BackupSet.Type.ValueType  # 0
            TYPE_AUTO: PolicySettings.Scheduling.BackupSet.Type.ValueType  # 1
            TYPE_FULL: PolicySettings.Scheduling.BackupSet.Type.ValueType  # 2
            TYPE_INCREMENTAL: PolicySettings.Scheduling.BackupSet.Type.ValueType  # 3
            TYPE_DIFFERENTIAL: PolicySettings.Scheduling.BackupSet.Type.ValueType  # 4

            @typing.final
            class Time(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                WEEKDAYS_FIELD_NUMBER: builtins.int
                REPEAT_AT_FIELD_NUMBER: builtins.int
                REPEAT_EVERY_FIELD_NUMBER: builtins.int
                TIME_FROM_FIELD_NUMBER: builtins.int
                TIME_TO_FIELD_NUMBER: builtins.int
                MONTHDAYS_FIELD_NUMBER: builtins.int
                INCLUDE_LAST_DAY_OF_MONTH_FIELD_NUMBER: builtins.int
                MONTHS_FIELD_NUMBER: builtins.int
                TYPE_FIELD_NUMBER: builtins.int
                RUN_LATER_FIELD_NUMBER: builtins.int
                include_last_day_of_month: builtins.bool
                """If set to true, last day of month will activate
                the policy.
                """
                type: global___PolicySettings.RepeatePeriod.ValueType
                """Possible types: `REPEATE_PERIOD_UNSPECIFIED`, `HOURLY`, `DAILY`, `WEEKLY`, `MONTHLY`."""
                run_later: builtins.bool
                """If the machine is off, launch missed tasks on boot up."""
                @property
                def weekdays(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___PolicySettings.Day.ValueType]:
                    """Days in a week to perform a backup."""

                @property
                def repeat_at(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PolicySettings.TimeOfDay]:
                    """Time to repeat the backup."""

                @property
                def repeat_every(self) -> global___PolicySettings.Interval:
                    """Frequency of backup repetition."""

                @property
                def time_from(self) -> global___PolicySettings.TimeOfDay:
                    """The start time of the backup time interval."""

                @property
                def time_to(self) -> global___PolicySettings.TimeOfDay:
                    """The end time of the backup time interval."""

                @property
                def monthdays(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
                    """Days in a month to perform a backup.
                    Allowed values are from 1 to 31.
                    """

                @property
                def months(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
                    """Set of values. Allowed values form 1 to 12."""

                def __init__(
                    self,
                    *,
                    weekdays: collections.abc.Iterable[global___PolicySettings.Day.ValueType] | None = ...,
                    repeat_at: collections.abc.Iterable[global___PolicySettings.TimeOfDay] | None = ...,
                    repeat_every: global___PolicySettings.Interval | None = ...,
                    time_from: global___PolicySettings.TimeOfDay | None = ...,
                    time_to: global___PolicySettings.TimeOfDay | None = ...,
                    monthdays: collections.abc.Iterable[builtins.int] | None = ...,
                    include_last_day_of_month: builtins.bool = ...,
                    months: collections.abc.Iterable[builtins.int] | None = ...,
                    type: global___PolicySettings.RepeatePeriod.ValueType = ...,
                    run_later: builtins.bool = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["repeat_every", b"repeat_every", "time_from", b"time_from", "time_to", b"time_to"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["include_last_day_of_month", b"include_last_day_of_month", "monthdays", b"monthdays", "months", b"months", "repeat_at", b"repeat_at", "repeat_every", b"repeat_every", "run_later", b"run_later", "time_from", b"time_from", "time_to", b"time_to", "type", b"type", "weekdays", b"weekdays"]) -> None: ...

            @typing.final
            class SinceLastExecTime(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                DELAY_FIELD_NUMBER: builtins.int
                @property
                def delay(self) -> global___PolicySettings.Interval:
                    """The interval between backups."""

                def __init__(
                    self,
                    *,
                    delay: global___PolicySettings.Interval | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["delay", b"delay"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["delay", b"delay"]) -> None: ...

            TIME_FIELD_NUMBER: builtins.int
            SINCE_LAST_EXEC_TIME_FIELD_NUMBER: builtins.int
            TYPE_FIELD_NUMBER: builtins.int
            type: global___PolicySettings.Scheduling.BackupSet.Type.ValueType
            """BackupSet type -- one of incr, full, differential or auto.
            if custom scheme is used the BackupSet type should be specified
            """
            @property
            def time(self) -> global___PolicySettings.Scheduling.BackupSet.Time: ...
            @property
            def since_last_exec_time(self) -> global___PolicySettings.Scheduling.BackupSet.SinceLastExecTime: ...
            def __init__(
                self,
                *,
                time: global___PolicySettings.Scheduling.BackupSet.Time | None = ...,
                since_last_exec_time: global___PolicySettings.Scheduling.BackupSet.SinceLastExecTime | None = ...,
                type: global___PolicySettings.Scheduling.BackupSet.Type.ValueType = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["setting", b"setting", "since_last_exec_time", b"since_last_exec_time", "time", b"time"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["setting", b"setting", "since_last_exec_time", b"since_last_exec_time", "time", b"time", "type", b"type"]) -> None: ...
            def WhichOneof(self, oneof_group: typing.Literal["setting", b"setting"]) -> typing.Literal["time", "since_last_exec_time"] | None: ...

        BACKUP_SETS_FIELD_NUMBER: builtins.int
        ENABLED_FIELD_NUMBER: builtins.int
        MAX_PARALLEL_BACKUPS_FIELD_NUMBER: builtins.int
        RAND_MAX_DELAY_FIELD_NUMBER: builtins.int
        SCHEME_FIELD_NUMBER: builtins.int
        WEEKLY_BACKUP_DAY_FIELD_NUMBER: builtins.int
        TASK_FAILURE_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """If true, the backup schedule will be enabled."""
        max_parallel_backups: builtins.int
        """Max number of backup processes allowed to run in parallel. Unlimited if not set."""
        scheme: global___PolicySettings.Scheduling.Scheme.ValueType
        """A backup scheme. Available values: `simple`, `always_full`, `always_incremental`, `weekly_incremental`, `weekly_full_daily_incremental`, `custom`, `cdp`."""
        weekly_backup_day: global___PolicySettings.Day.ValueType
        """A day of week to start weekly backups."""
        @property
        def backup_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PolicySettings.Scheduling.BackupSet]:
            """A list of schedules with backup sets that compose the whole scheme."""

        @property
        def rand_max_delay(self) -> global___PolicySettings.Interval:
            """Configuration of the random delay between the execution of parallel tasks."""

        @property
        def task_failure(self) -> global___PolicySettings.RetriesConfiguration:
            """Task failure settings in case of failure of scheduled task, not applicable to  manually launched tasks"""

        def __init__(
            self,
            *,
            backup_sets: collections.abc.Iterable[global___PolicySettings.Scheduling.BackupSet] | None = ...,
            enabled: builtins.bool = ...,
            max_parallel_backups: builtins.int = ...,
            rand_max_delay: global___PolicySettings.Interval | None = ...,
            scheme: global___PolicySettings.Scheduling.Scheme.ValueType = ...,
            weekly_backup_day: global___PolicySettings.Day.ValueType = ...,
            task_failure: global___PolicySettings.RetriesConfiguration | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["rand_max_delay", b"rand_max_delay", "task_failure", b"task_failure"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["backup_sets", b"backup_sets", "enabled", b"enabled", "max_parallel_backups", b"max_parallel_backups", "rand_max_delay", b"rand_max_delay", "scheme", b"scheme", "task_failure", b"task_failure", "weekly_backup_day", b"weekly_backup_day"]) -> None: ...

    @typing.final
    class FileFilters(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EXCLUSION_MASKS_FIELD_NUMBER: builtins.int
        INCLUSION_MASKS_FIELD_NUMBER: builtins.int
        @property
        def exclusion_masks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Do not backup files that match the following criteria"""

        @property
        def inclusion_masks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Backup only files that match the following criteria"""

        def __init__(
            self,
            *,
            exclusion_masks: collections.abc.Iterable[builtins.str] | None = ...,
            inclusion_masks: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["exclusion_masks", b"exclusion_masks", "inclusion_masks", b"inclusion_masks"]) -> None: ...

    @typing.final
    class PrePostCommand(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CMD_FIELD_NUMBER: builtins.int
        ARGS_FIELD_NUMBER: builtins.int
        ENABLED_FIELD_NUMBER: builtins.int
        STOP_ON_ERROR_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        WAIT_FIELD_NUMBER: builtins.int
        WORKDIR_FIELD_NUMBER: builtins.int
        cmd: builtins.str
        """Command to execute"""
        args: builtins.str
        """Command args"""
        enabled: builtins.bool
        """Is command enabled"""
        stop_on_error: builtins.bool
        """Stop backup execution on error"""
        type: global___PolicySettings.CommandType.ValueType
        """Type of command: pre or post"""
        wait: builtins.bool
        """Wait command finish before launching backup"""
        workdir: builtins.str
        """Workdir for command execution"""
        def __init__(
            self,
            *,
            cmd: builtins.str = ...,
            args: builtins.str = ...,
            enabled: builtins.bool = ...,
            stop_on_error: builtins.bool = ...,
            type: global___PolicySettings.CommandType.ValueType = ...,
            wait: builtins.bool = ...,
            workdir: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["args", b"args", "cmd", b"cmd", "enabled", b"enabled", "stop_on_error", b"stop_on_error", "type", b"type", "wait", b"wait", "workdir", b"workdir"]) -> None: ...

    COMPRESSION_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    MULTI_VOLUME_SNAPSHOTTING_ENABLED_FIELD_NUMBER: builtins.int
    PRESERVE_FILE_SECURITY_SETTINGS_FIELD_NUMBER: builtins.int
    REATTEMPTS_FIELD_NUMBER: builtins.int
    SILENT_MODE_ENABLED_FIELD_NUMBER: builtins.int
    SPLITTING_FIELD_NUMBER: builtins.int
    VM_SNAPSHOT_REATTEMPTS_FIELD_NUMBER: builtins.int
    VSS_FIELD_NUMBER: builtins.int
    ARCHIVE_FIELD_NUMBER: builtins.int
    PERFORMANCE_WINDOW_FIELD_NUMBER: builtins.int
    RETENTION_FIELD_NUMBER: builtins.int
    SCHEDULING_FIELD_NUMBER: builtins.int
    CBT_FIELD_NUMBER: builtins.int
    FAST_BACKUP_ENABLED_FIELD_NUMBER: builtins.int
    QUIESCE_SNAPSHOTTING_ENABLED_FIELD_NUMBER: builtins.int
    FILE_FILTERS_FIELD_NUMBER: builtins.int
    SECTOR_BY_SECTOR_FIELD_NUMBER: builtins.int
    VALIDATION_ENABLED_FIELD_NUMBER: builtins.int
    LVM_SNAPSHOTTING_ENABLED_FIELD_NUMBER: builtins.int
    PRE_POST_COMMANDS_FIELD_NUMBER: builtins.int
    compression: global___PolicySettings.Compression.ValueType
    """Archive compression level."""
    format: global___Format.ValueType
    """Format of the Acronis backup archive."""
    multi_volume_snapshotting_enabled: builtins.bool
    """If true, snapshots of multiple volumes will be taken simultaneously."""
    preserve_file_security_settings: builtins.bool
    """If true, the file security settings will be preserved.
    Deprecated.
    """
    silent_mode_enabled: builtins.bool
    """If true, a user interaction will be avoided when possible. Equals to false if value is not specified."""
    cbt: global___PolicySettings.ChangedBlockTracking.ValueType
    """A configuration of Changed Block Tracking (CBT)."""
    fast_backup_enabled: builtins.bool
    """If true, determines whether a file has changed by the file size and timestamp. Otherwise, the entire file contents are compared to those stored in the backup."""
    quiesce_snapshotting_enabled: builtins.bool
    """If true, a quiesced snapshot of the virtual machine will be taken.
    Deprecated.
    """
    sector_by_sector: builtins.bool
    """A sector-by-sector backup of a disk or volume creates a backup copy of all sectors of the disk or volume, 
    including those that do not contain data.
    Therefore, the size of such a backup copy will be equal to the size of the original disk or volume. 
    This method can be used to back up a disk or volume with an unsupported file system.
    """
    validation_enabled: builtins.bool
    """Validation is a time-consuming process, even with incremental or differential backups of small amounts of data. 
    This is because not only the data physically contained in the backup copy is verified,
    but all data restored when it is selected. 
    This option requires access to previously created backup copies.
    """
    lvm_snapshotting_enabled: builtins.bool
    """LVM will be used to create the volume snapshot.
    If LVM fails to create a snapshot (for example, because there is not enough free space),
    the software will create the snapshot itself.
    """
    @property
    def reattempts(self) -> global___PolicySettings.RetriesConfiguration:
        """Configuration of retries on recoverable errors during the backup operations like reconnection to destination. No attempts to fix recoverable errors will be made if retry configuration is not set."""

    @property
    def splitting(self) -> global___PolicySettings.Splitting:
        """Determines the size to split backups on. Splitting is not performed if value is not specified."""

    @property
    def vm_snapshot_reattempts(self) -> global___PolicySettings.RetriesConfiguration:
        """Configuration of retries on errors during the creation of the virtual machine snapshot. No attempts to fix recoverable errors will be made if retry configuration is not set."""

    @property
    def vss(self) -> global___PolicySettings.VolumeShadowCopyServiceSettings:
        """Settings for the Volume Shadow Copy Service (VSS) provider. If not set, no VSS provider is used."""

    @property
    def archive(self) -> global___PolicySettings.ArchiveProperties:
        """The archive properties."""

    @property
    def performance_window(self) -> global___PolicySettings.PerformanceWindow:
        """Time windows for performance limitations of backup and storage maintenance operations."""

    @property
    def retention(self) -> global___PolicySettings.Retention:
        """Configuration of backup retention rules."""

    @property
    def scheduling(self) -> global___PolicySettings.Scheduling:
        """Configuration of the backup schedule."""

    @property
    def file_filters(self) -> global___PolicySettings.FileFilters:
        """File filters to specify masks of files to backup or to exclude of backuping"""

    @property
    def pre_post_commands(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PolicySettings.PrePostCommand]:
        """Commands to launch before or after backup execution"""

    def __init__(
        self,
        *,
        compression: global___PolicySettings.Compression.ValueType = ...,
        format: global___Format.ValueType = ...,
        multi_volume_snapshotting_enabled: builtins.bool = ...,
        preserve_file_security_settings: builtins.bool = ...,
        reattempts: global___PolicySettings.RetriesConfiguration | None = ...,
        silent_mode_enabled: builtins.bool = ...,
        splitting: global___PolicySettings.Splitting | None = ...,
        vm_snapshot_reattempts: global___PolicySettings.RetriesConfiguration | None = ...,
        vss: global___PolicySettings.VolumeShadowCopyServiceSettings | None = ...,
        archive: global___PolicySettings.ArchiveProperties | None = ...,
        performance_window: global___PolicySettings.PerformanceWindow | None = ...,
        retention: global___PolicySettings.Retention | None = ...,
        scheduling: global___PolicySettings.Scheduling | None = ...,
        cbt: global___PolicySettings.ChangedBlockTracking.ValueType = ...,
        fast_backup_enabled: builtins.bool = ...,
        quiesce_snapshotting_enabled: builtins.bool = ...,
        file_filters: global___PolicySettings.FileFilters | None = ...,
        sector_by_sector: builtins.bool = ...,
        validation_enabled: builtins.bool = ...,
        lvm_snapshotting_enabled: builtins.bool = ...,
        pre_post_commands: collections.abc.Iterable[global___PolicySettings.PrePostCommand] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["archive", b"archive", "file_filters", b"file_filters", "performance_window", b"performance_window", "reattempts", b"reattempts", "retention", b"retention", "scheduling", b"scheduling", "splitting", b"splitting", "vm_snapshot_reattempts", b"vm_snapshot_reattempts", "vss", b"vss"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["archive", b"archive", "cbt", b"cbt", "compression", b"compression", "fast_backup_enabled", b"fast_backup_enabled", "file_filters", b"file_filters", "format", b"format", "lvm_snapshotting_enabled", b"lvm_snapshotting_enabled", "multi_volume_snapshotting_enabled", b"multi_volume_snapshotting_enabled", "performance_window", b"performance_window", "pre_post_commands", b"pre_post_commands", "preserve_file_security_settings", b"preserve_file_security_settings", "quiesce_snapshotting_enabled", b"quiesce_snapshotting_enabled", "reattempts", b"reattempts", "retention", b"retention", "scheduling", b"scheduling", "sector_by_sector", b"sector_by_sector", "silent_mode_enabled", b"silent_mode_enabled", "splitting", b"splitting", "validation_enabled", b"validation_enabled", "vm_snapshot_reattempts", b"vm_snapshot_reattempts", "vss", b"vss"]) -> None: ...

global___PolicySettings = PolicySettings

@typing.final
class PolicyApplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicyApplication._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: PolicyApplication._Status.ValueType  # 0
        OK: PolicyApplication._Status.ValueType  # 1
        """Application is applied and everything is OK."""
        RUNNING: PolicyApplication._Status.ValueType  # 2
        """Application is currently running."""
        DISABLED: PolicyApplication._Status.ValueType  # 3
        """Application is disabled."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: PolicyApplication.Status.ValueType  # 0
    OK: PolicyApplication.Status.ValueType  # 1
    """Application is applied and everything is OK."""
    RUNNING: PolicyApplication.Status.ValueType  # 2
    """Application is currently running."""
    DISABLED: PolicyApplication.Status.ValueType  # 3
    """Application is disabled."""

    POLICY_ID_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    IS_PROCESSING_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """Policy ID."""
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    enabled: builtins.bool
    status: global___PolicyApplication.Status.ValueType
    is_processing: builtins.bool
    """If true, then the policy is in in the process of binding to the instance."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
        compute_instance_id: builtins.str = ...,
        enabled: builtins.bool = ...,
        status: global___PolicyApplication.Status.ValueType = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        is_processing: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "created_at", b"created_at", "enabled", b"enabled", "is_processing", b"is_processing", "policy_id", b"policy_id", "status", b"status"]) -> None: ...

global___PolicyApplication = PolicyApplication



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.baremetal.v1alpha.dhcp_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PrivateSubnet(google.protobuf.message.Message):
    """A PrivateSubnet resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PrivateSubnet._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: PrivateSubnet._Status.ValueType  # 0
        """Unspecified private subnet status."""
        CREATING: PrivateSubnet._Status.ValueType  # 1
        """Private subnet is being created."""
        READY: PrivateSubnet._Status.ValueType  # 2
        """Private subnet is ready to use."""
        UPDATING: PrivateSubnet._Status.ValueType  # 3
        """Private subnet is being updated."""
        DELETING: PrivateSubnet._Status.ValueType  # 4
        """Private subnet is being deleted."""
        ERROR: PrivateSubnet._Status.ValueType  # 5
        """Private subnet encountered a problem and cannot operate."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Private subnet status."""

    STATUS_UNSPECIFIED: PrivateSubnet.Status.ValueType  # 0
    """Unspecified private subnet status."""
    CREATING: PrivateSubnet.Status.ValueType  # 1
    """Private subnet is being created."""
    READY: PrivateSubnet.Status.ValueType  # 2
    """Private subnet is ready to use."""
    UPDATING: PrivateSubnet.Status.ValueType  # 3
    """Private subnet is being updated."""
    DELETING: PrivateSubnet.Status.ValueType  # 4
    """Private subnet is being deleted."""
    ERROR: PrivateSubnet.Status.ValueType  # 5
    """Private subnet encountered a problem and cannot operate."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class VrfOptions(google.protobuf.message.Message):
        """VRF options for the private subnet."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        VRF_ID_FIELD_NUMBER: builtins.int
        CIDR_FIELD_NUMBER: builtins.int
        DHCP_OPTIONS_FIELD_NUMBER: builtins.int
        GATEWAY_IP_FIELD_NUMBER: builtins.int
        vrf_id: builtins.str
        """ID of the VRF."""
        cidr: builtins.str
        """CIDR block for the subnet."""
        gateway_ip: builtins.str
        """Gateway IP address for the subnet."""
        @property
        def dhcp_options(self) -> yandex.cloud.baremetal.v1alpha.dhcp_pb2.DhcpOptions:
            """DHCP options for the subnet."""

        def __init__(
            self,
            *,
            vrf_id: builtins.str = ...,
            cidr: builtins.str = ...,
            dhcp_options: yandex.cloud.baremetal.v1alpha.dhcp_pb2.DhcpOptions | None = ...,
            gateway_ip: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["dhcp_options", b"dhcp_options"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["cidr", b"cidr", "dhcp_options", b"dhcp_options", "gateway_ip", b"gateway_ip", "vrf_id", b"vrf_id"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    HARDWARE_POOL_ID_FIELD_NUMBER: builtins.int
    VRF_OPTIONS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the private subnet."""
    cloud_id: builtins.str
    """ID of the cloud that the private subnet belongs to."""
    folder_id: builtins.str
    """ID of the folder that the private subnet belongs to."""
    name: builtins.str
    """Name of the private subnet.
    The name is unique within the folder.
    """
    description: builtins.str
    """Optional description of the private subnet."""
    status: global___PrivateSubnet.Status.ValueType
    """Status of the private subnet."""
    zone_id: builtins.str
    """ID of the availability zone where the server resides."""
    hardware_pool_id: builtins.str
    """ID of the hardware pool that the private subnet belongs to."""
    @property
    def vrf_options(self) -> global___PrivateSubnet.VrfOptions:
        """Optional VRF options for the private subnet. If missing, the private subnet will be unrouted,
        i.e. it will lack a DHCP server and routing capabilities between this subnet and other private
        subnets.
        """

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        status: global___PrivateSubnet.Status.ValueType = ...,
        zone_id: builtins.str = ...,
        hardware_pool_id: builtins.str = ...,
        vrf_options: global___PrivateSubnet.VrfOptions | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "vrf_options", b"vrf_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "hardware_pool_id", b"hardware_pool_id", "id", b"id", "labels", b"labels", "name", b"name", "status", b"status", "vrf_options", b"vrf_options", "zone_id", b"zone_id"]) -> None: ...

global___PrivateSubnet = PrivateSubnet



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.empty_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.connectionmanager.v1.common_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class KafkaSaslSecurity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Mechanism:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _MechanismEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[KafkaSaslSecurity._Mechanism.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        MECHANISM_UNSPECIFIED: KafkaSaslSecurity._Mechanism.ValueType  # 0
        PLAIN: KafkaSaslSecurity._Mechanism.ValueType  # 1
        SCRAM_SHA256: KafkaSaslSecurity._Mechanism.ValueType  # 2
        SCRAM_SHA512: KafkaSaslSecurity._Mechanism.ValueType  # 3

    class Mechanism(_Mechanism, metaclass=_MechanismEnumTypeWrapper): ...
    MECHANISM_UNSPECIFIED: KafkaSaslSecurity.Mechanism.ValueType  # 0
    PLAIN: KafkaSaslSecurity.Mechanism.ValueType  # 1
    SCRAM_SHA256: KafkaSaslSecurity.Mechanism.ValueType  # 2
    SCRAM_SHA512: KafkaSaslSecurity.Mechanism.ValueType  # 3

    USER_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    SUPPORTED_MECHANISMS_FIELD_NUMBER: builtins.int
    user: builtins.str
    @property
    def password(self) -> yandex.cloud.connectionmanager.v1.common_pb2.Password: ...
    @property
    def supported_mechanisms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___KafkaSaslSecurity.Mechanism.ValueType]: ...
    def __init__(
        self,
        *,
        user: builtins.str = ...,
        password: yandex.cloud.connectionmanager.v1.common_pb2.Password | None = ...,
        supported_mechanisms: collections.abc.Iterable[global___KafkaSaslSecurity.Mechanism.ValueType] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["password", b"password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["password", b"password", "supported_mechanisms", b"supported_mechanisms", "user", b"user"]) -> None: ...

global___KafkaSaslSecurity = KafkaSaslSecurity

@typing.final
class KafkaAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SASL_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    @property
    def sasl(self) -> global___KafkaSaslSecurity: ...
    @property
    def disabled(self) -> google.protobuf.empty_pb2.Empty: ...
    def __init__(
        self,
        *,
        sasl: global___KafkaSaslSecurity | None = ...,
        disabled: google.protobuf.empty_pb2.Empty | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["disabled", b"disabled", "sasl", b"sasl", "security", b"security"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["disabled", b"disabled", "sasl", b"sasl", "security", b"security"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["security", b"security"]) -> typing.Literal["sasl", "disabled"] | None: ...

global___KafkaAuth = KafkaAuth

@typing.final
class KafkaCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Host(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Health:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[KafkaCluster.Host._Health.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            HEALTH_UNSPECIFIED: KafkaCluster.Host._Health.ValueType  # 0
            """Host is in unknown state (we have no data)"""
            ALIVE: KafkaCluster.Host._Health.ValueType  # 1
            """Host is alive and well (all services are alive)"""
            DEAD: KafkaCluster.Host._Health.ValueType  # 2
            """Host is inoperable (it cannot perform any of its essential functions)"""
            DEGRADED: KafkaCluster.Host._Health.ValueType  # 3
            """Host is partially alive (it can perform some of its essential functions)"""

        class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
        HEALTH_UNSPECIFIED: KafkaCluster.Host.Health.ValueType  # 0
        """Host is in unknown state (we have no data)"""
        ALIVE: KafkaCluster.Host.Health.ValueType  # 1
        """Host is alive and well (all services are alive)"""
        DEAD: KafkaCluster.Host.Health.ValueType  # 2
        """Host is inoperable (it cannot perform any of its essential functions)"""
        DEGRADED: KafkaCluster.Host.Health.ValueType  # 3
        """Host is partially alive (it can perform some of its essential functions)"""

        HOST_FIELD_NUMBER: builtins.int
        PORT_FIELD_NUMBER: builtins.int
        HEALTH_FIELD_NUMBER: builtins.int
        host: builtins.str
        port: builtins.int
        health: global___KafkaCluster.Host.Health.ValueType
        def __init__(
            self,
            *,
            host: builtins.str = ...,
            port: builtins.int = ...,
            health: global___KafkaCluster.Host.Health.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["health", b"health", "host", b"host", "port", b"port"]) -> None: ...

    HOSTS_FIELD_NUMBER: builtins.int
    TLS_PARAMS_FIELD_NUMBER: builtins.int
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___KafkaCluster.Host]: ...
    @property
    def tls_params(self) -> yandex.cloud.connectionmanager.v1.common_pb2.TLSParams: ...
    def __init__(
        self,
        *,
        hosts: collections.abc.Iterable[global___KafkaCluster.Host] | None = ...,
        tls_params: yandex.cloud.connectionmanager.v1.common_pb2.TLSParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tls_params", b"tls_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hosts", b"hosts", "tls_params", b"tls_params"]) -> None: ...

global___KafkaCluster = KafkaCluster

@typing.final
class KafkaConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    MANAGED_CLUSTER_ID_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    managed_cluster_id: builtins.str
    """When creating/updating Connection, the field "managed_cluster_id" is
    mutually exclusive with "cluster".
    """
    @property
    def cluster(self) -> global___KafkaCluster:
        """When creating/updating Connection, the field "cluster" is mutually
        exclusive with "managed_cluster_id".
        """

    @property
    def auth(self) -> global___KafkaAuth: ...
    def __init__(
        self,
        *,
        cluster: global___KafkaCluster | None = ...,
        managed_cluster_id: builtins.str = ...,
        auth: global___KafkaAuth | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auth", b"auth", "cluster", b"cluster"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auth", b"auth", "cluster", b"cluster", "managed_cluster_id", b"managed_cluster_id"]) -> None: ...

global___KafkaConnection = KafkaConnection



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.baremetal.v1alpha.disk_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _StoragePartitionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StoragePartitionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_StoragePartitionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STORAGE_PARTITION_TYPE_UNSPECIFIED: _StoragePartitionType.ValueType  # 0
    """Unspecified storage partition type."""
    EXT4: _StoragePartitionType.ValueType  # 1
    """ext4 file system partition type."""
    SWAP: _StoragePartitionType.ValueType  # 2
    """Swap partition type."""
    EXT3: _StoragePartitionType.ValueType  # 3
    """ext3 file system partition type."""
    XFS: _StoragePartitionType.ValueType  # 4
    """XFS file system partition type."""

class StoragePartitionType(_StoragePartitionType, metaclass=_StoragePartitionTypeEnumTypeWrapper):
    """Storage partition type."""

STORAGE_PARTITION_TYPE_UNSPECIFIED: StoragePartitionType.ValueType  # 0
"""Unspecified storage partition type."""
EXT4: StoragePartitionType.ValueType  # 1
"""ext4 file system partition type."""
SWAP: StoragePartitionType.ValueType  # 2
"""Swap partition type."""
EXT3: StoragePartitionType.ValueType  # 3
"""ext3 file system partition type."""
XFS: StoragePartitionType.ValueType  # 4
"""XFS file system partition type."""
global___StoragePartitionType = StoragePartitionType

class _RaidType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RaidTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RaidType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RAID_TYPE_UNSPECIFIED: _RaidType.ValueType  # 0
    """Unspecified RAID configuration."""
    RAID0: _RaidType.ValueType  # 1
    """RAID0 configuration."""
    RAID1: _RaidType.ValueType  # 2
    """RAID1 configuration."""
    RAID10: _RaidType.ValueType  # 3
    """RAID10 configuration."""

class RaidType(_RaidType, metaclass=_RaidTypeEnumTypeWrapper):
    """RaidType represents different RAID configurations."""

RAID_TYPE_UNSPECIFIED: RaidType.ValueType  # 0
"""Unspecified RAID configuration."""
RAID0: RaidType.ValueType  # 1
"""RAID0 configuration."""
RAID1: RaidType.ValueType  # 2
"""RAID1 configuration."""
RAID10: RaidType.ValueType  # 3
"""RAID10 configuration."""
global___RaidType = RaidType

@typing.final
class StoragePartition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    SIZE_GIB_FIELD_NUMBER: builtins.int
    MOUNT_POINT_FIELD_NUMBER: builtins.int
    type: global___StoragePartitionType.ValueType
    """Partition type."""
    size_gib: builtins.int
    """Size of the storage partition in gibibytes (2^30 bytes)."""
    mount_point: builtins.str
    """Storage mount point."""
    def __init__(
        self,
        *,
        type: global___StoragePartitionType.ValueType = ...,
        size_gib: builtins.int = ...,
        mount_point: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mount_point", b"mount_point", "size_gib", b"size_gib", "type", b"type"]) -> None: ...

global___StoragePartition = StoragePartition

@typing.final
class Storage(google.protobuf.message.Message):
    """Storage, a OS-level storage entity used for creating partitions. For example, this could
    represent a plain disk or a software RAID of disks.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARTITIONS_FIELD_NUMBER: builtins.int
    DISK_FIELD_NUMBER: builtins.int
    RAID_FIELD_NUMBER: builtins.int
    @property
    def partitions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StoragePartition]:
        """Array of partitions created on the storage."""

    @property
    def disk(self) -> yandex.cloud.baremetal.v1alpha.disk_pb2.Disk:
        """Disk storage."""

    @property
    def raid(self) -> global___Raid:
        """RAID storage."""

    def __init__(
        self,
        *,
        partitions: collections.abc.Iterable[global___StoragePartition] | None = ...,
        disk: yandex.cloud.baremetal.v1alpha.disk_pb2.Disk | None = ...,
        raid: global___Raid | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["disk", b"disk", "raid", b"raid", "storage_type", b"storage_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["disk", b"disk", "partitions", b"partitions", "raid", b"raid", "storage_type", b"storage_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["storage_type", b"storage_type"]) -> typing.Literal["disk", "raid"] | None: ...

global___Storage = Storage

@typing.final
class Raid(google.protobuf.message.Message):
    """RAID storage."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DISKS_FIELD_NUMBER: builtins.int
    type: global___RaidType.ValueType
    """RAID type."""
    @property
    def disks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.baremetal.v1alpha.disk_pb2.Disk]:
        """Array of disks in the RAID configuration."""

    def __init__(
        self,
        *,
        type: global___RaidType.ValueType = ...,
        disks: collections.abc.Iterable[yandex.cloud.baremetal.v1alpha.disk_pb2.Disk] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disks", b"disks", "type", b"type"]) -> None: ...

global___Raid = Raid



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/storage.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/storage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.baremetal.v1alpha import disk_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_disk__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/baremetal/v1alpha/storage.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a)yandex/cloud/baremetal/v1alpha/disk.proto\"}\n\x10StoragePartition\x12\x42\n\x04type\x18\x01 \x01(\x0e\x32\x34.yandex.cloud.baremetal.v1alpha.StoragePartitionType\x12\x10\n\x08size_gib\x18\x02 \x01(\x03\x12\x13\n\x0bmount_point\x18\x03 \x01(\t\"\xd7\x01\n\x07Storage\x12\x44\n\npartitions\x18\x03 \x03(\x0b\x32\x30.yandex.cloud.baremetal.v1alpha.StoragePartition\x12\x34\n\x04\x64isk\x18\x04 \x01(\x0b\x32$.yandex.cloud.baremetal.v1alpha.DiskH\x00\x12\x34\n\x04raid\x18\x05 \x01(\x0b\x32$.yandex.cloud.baremetal.v1alpha.RaidH\x00\x42\x0e\n\x0cstorage_typeJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"s\n\x04Raid\x12\x36\n\x04type\x18\x01 \x01(\x0e\x32(.yandex.cloud.baremetal.v1alpha.RaidType\x12\x33\n\x05\x64isks\x18\x02 \x03(\x0b\x32$.yandex.cloud.baremetal.v1alpha.Disk*e\n\x14StoragePartitionType\x12&\n\"STORAGE_PARTITION_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x45XT4\x10\x01\x12\x08\n\x04SWAP\x10\x02\x12\x08\n\x04\x45XT3\x10\x03\x12\x07\n\x03XFS\x10\x04*G\n\x08RaidType\x12\x19\n\x15RAID_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05RAID0\x10\x01\x12\t\n\x05RAID1\x10\x02\x12\n\n\x06RAID10\x10\x03\x42r\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.storage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_STORAGEPARTITIONTYPE']._serialized_start=585
  _globals['_STORAGEPARTITIONTYPE']._serialized_end=686
  _globals['_RAIDTYPE']._serialized_start=688
  _globals['_RAIDTYPE']._serialized_end=759
  _globals['_STORAGEPARTITION']._serialized_start=123
  _globals['_STORAGEPARTITION']._serialized_end=248
  _globals['_STORAGE']._serialized_start=251
  _globals['_STORAGE']._serialized_end=466
  _globals['_RAID']._serialized_start=468
  _globals['_RAID']._serialized_end=583
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.struct_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class NodeExecutionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NODE_ID_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that will be matched with Node ACL."""
    node_id: builtins.str
    """ID of the Node to perform request on."""
    @property
    def input(self) -> google.protobuf.struct_pb2.Struct:
        """Input data for the execution."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        node_id: builtins.str = ...,
        input: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["input", b"input"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "input", b"input", "node_id", b"node_id"]) -> None: ...

global___NodeExecutionRequest = NodeExecutionRequest

@typing.final
class NodeExecutionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUT_FIELD_NUMBER: builtins.int
    @property
    def output(self) -> google.protobuf.struct_pb2.Struct:
        """Result of the execution."""

    def __init__(
        self,
        *,
        output: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["output", b"output"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["output", b"output"]) -> None: ...

global___NodeExecutionResponse = NodeExecutionResponse

@typing.final
class AliasExecutionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    ALIAS_NAME_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that will be matched with Alias ACL"""
    alias_name: builtins.str
    """Name of the Alias to perform request on"""
    @property
    def input(self) -> google.protobuf.struct_pb2.Struct:
        """Input data for the execution"""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        alias_name: builtins.str = ...,
        input: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["input", b"input"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["alias_name", b"alias_name", "folder_id", b"folder_id", "input", b"input"]) -> None: ...

global___AliasExecutionRequest = AliasExecutionRequest

@typing.final
class AliasExecutionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUT_FIELD_NUMBER: builtins.int
    @property
    def output(self) -> google.protobuf.struct_pb2.Struct:
        """Result of the execution"""

    def __init__(
        self,
        *,
        output: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["output", b"output"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["output", b"output"]) -> None: ...

global___AliasExecutionResponse = AliasExecutionResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import yandex.cloud.cic.v1.peering_pb2
import yandex.cloud.cic.v1.private_connection_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetPrivateConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_connection_id: builtins.str
    """ID of the PrivateConnection resource to return.
    To get the privateConnection ID use a [PrivateConnectionService.List] request.
    """
    def __init__(
        self,
        *,
        private_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_connection_id", b"private_connection_id"]) -> None: ...

global___GetPrivateConnectionRequest = GetPrivateConnectionRequest

@typing.final
class ListPrivateConnectionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list PrivateConnection resources.
    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListPrivatesConnectionResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests. Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListPrivatesConnectionResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [Subnet.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListPrivateConnectionsRequest = ListPrivateConnectionsRequest

@typing.final
class ListPrivateConnectionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CONNECTIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListPrivateConnectionsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListPrivateConnectionsRequest.page_token] query parameter
    in the next list request. Subsequent list requests will have their own
    [next_page_token] to continue paging through the results.
    """
    @property
    def private_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cic.v1.private_connection_pb2.PrivateConnection]:
        """List of PrivateConnection resources."""

    def __init__(
        self,
        *,
        private_connections: collections.abc.Iterable[yandex.cloud.cic.v1.private_connection_pb2.PrivateConnection] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "private_connections", b"private_connections"]) -> None: ...

global___ListPrivateConnectionsResponse = ListPrivateConnectionsResponse

@typing.final
class CreatePrivateConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    REGION_ID_FIELD_NUMBER: builtins.int
    TRUNK_CONNECTION_ID_FIELD_NUMBER: builtins.int
    VLAN_ID_FIELD_NUMBER: builtins.int
    IPV4_PEERING_FIELD_NUMBER: builtins.int
    IPV4_STATIC_ROUTES_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the privateConnection.
    The name must be unique within the folder.
    Value must match the regular expression ``\\|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?``.
    """
    description: builtins.str
    """Optional description of the privateConnection. 0-256 characters long."""
    folder_id: builtins.str
    """ID of the folder that the privateConnection belongs to."""
    region_id: builtins.str
    """ID of the region that the privateConnection belongs to."""
    trunk_connection_id: builtins.str
    """ID of the trunk_connection that the privateConnection belongs to."""
    @property
    def vlan_id(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """VLAN_ID that the privateConnection uses in multiplexing.
        Not used in connections over partners-II
        Value range: [1, 4095]
        """

    @property
    def ipv4_peering(self) -> yandex.cloud.cic.v1.peering_pb2.Peering:
        """IPv4 peering config of connection"""

    @property
    def ipv4_static_routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cic.v1.private_connection_pb2.PrivateConnection.StaticRoute]:
        """IPv4 StaticRoute config of connection"""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels, `key:value` pairs.
        No more than 64 per resource.
        The maximum string length in characters for each value is 63.
        Each value must match the regular expression `[-_0-9a-z]*`.
        The string length in characters for each key must be 1-63.
        Each key must match the regular expression `[a-z][-_0-9a-z]*`.
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        folder_id: builtins.str = ...,
        region_id: builtins.str = ...,
        trunk_connection_id: builtins.str = ...,
        vlan_id: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ipv4_peering: yandex.cloud.cic.v1.peering_pb2.Peering | None = ...,
        ipv4_static_routes: collections.abc.Iterable[yandex.cloud.cic.v1.private_connection_pb2.PrivateConnection.StaticRoute] | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ipv4_peering", b"ipv4_peering", "vlan_id", b"vlan_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "ipv4_peering", b"ipv4_peering", "ipv4_static_routes", b"ipv4_static_routes", "labels", b"labels", "name", b"name", "region_id", b"region_id", "trunk_connection_id", b"trunk_connection_id", "vlan_id", b"vlan_id"]) -> None: ...

global___CreatePrivateConnectionRequest = CreatePrivateConnectionRequest

@typing.final
class CreatePrivateConnectionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_connection_id: builtins.str
    """ID of the PrivateConnection resource."""
    def __init__(
        self,
        *,
        private_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_connection_id", b"private_connection_id"]) -> None: ...

global___CreatePrivateConnectionMetadata = CreatePrivateConnectionMetadata

@typing.final
class UpdatePrivateConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    PRIVATE_CONNECTION_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    REGION_ID_FIELD_NUMBER: builtins.int
    TRUNK_CONNECTION_ID_FIELD_NUMBER: builtins.int
    VLAN_ID_FIELD_NUMBER: builtins.int
    IPV4_PEERING_FIELD_NUMBER: builtins.int
    IPV4_STATIC_ROUTES_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    private_connection_id: builtins.str
    """ID of the PrivateConnection resource."""
    name: builtins.str
    """Name of the privateConnection.
    The name must be unique within the folder.
    Value must match the regular expression ``\\|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?``.
    """
    description: builtins.str
    """Optional description of the privateConnection. 0-256 characters long."""
    region_id: builtins.str
    """ID of the region that the privateConnection belongs to."""
    trunk_connection_id: builtins.str
    """ID of the trunk_connection that the privateConnection belongs to."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the PrivateConnection resource are going to be updated."""

    @property
    def vlan_id(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """VLAN_ID that the privateConnection uses in multiplexing.
        Not used in connections over partners-II
        Value range: [1, 4095]
        """

    @property
    def ipv4_peering(self) -> yandex.cloud.cic.v1.peering_pb2.Peering:
        """IPv4 peering config of connection"""

    @property
    def ipv4_static_routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cic.v1.private_connection_pb2.PrivateConnection.StaticRoute]:
        """IPv4 StaticRoute config of connection"""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels, `key:value` pairs.
        No more than 64 per resource.
        The maximum string length in characters for each value is 63.
        Each value must match the regular expression `[-_0-9a-z]*`.
        The string length in characters for each key must be 1-63.
        Each key must match the regular expression `[a-z][-_0-9a-z]*`.
        """

    def __init__(
        self,
        *,
        private_connection_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        region_id: builtins.str = ...,
        trunk_connection_id: builtins.str = ...,
        vlan_id: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ipv4_peering: yandex.cloud.cic.v1.peering_pb2.Peering | None = ...,
        ipv4_static_routes: collections.abc.Iterable[yandex.cloud.cic.v1.private_connection_pb2.PrivateConnection.StaticRoute] | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ipv4_peering", b"ipv4_peering", "update_mask", b"update_mask", "vlan_id", b"vlan_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "ipv4_peering", b"ipv4_peering", "ipv4_static_routes", b"ipv4_static_routes", "labels", b"labels", "name", b"name", "private_connection_id", b"private_connection_id", "region_id", b"region_id", "trunk_connection_id", b"trunk_connection_id", "update_mask", b"update_mask", "vlan_id", b"vlan_id"]) -> None: ...

global___UpdatePrivateConnectionRequest = UpdatePrivateConnectionRequest

@typing.final
class UpdatePrivateConnectionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_connection_id: builtins.str
    """ID of the PrivateConnection resource."""
    def __init__(
        self,
        *,
        private_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_connection_id", b"private_connection_id"]) -> None: ...

global___UpdatePrivateConnectionMetadata = UpdatePrivateConnectionMetadata

@typing.final
class DeletePrivateConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_connection_id: builtins.str
    """ID of the PrivateConnection resource."""
    def __init__(
        self,
        *,
        private_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_connection_id", b"private_connection_id"]) -> None: ...

global___DeletePrivateConnectionRequest = DeletePrivateConnectionRequest

@typing.final
class DeletePrivateConnectionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_connection_id: builtins.str
    """ID of the PrivateConnection resource."""
    def __init__(
        self,
        *,
        private_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_connection_id", b"private_connection_id"]) -> None: ...

global___DeletePrivateConnectionMetadata = DeletePrivateConnectionMetadata

@typing.final
class UpsertStaticRouteRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CONNECTION_ID_FIELD_NUMBER: builtins.int
    IPV4_STATIC_ROUTES_FIELD_NUMBER: builtins.int
    private_connection_id: builtins.str
    """ID of the PrivateConnection resource."""
    @property
    def ipv4_static_routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cic.v1.private_connection_pb2.PrivateConnection.StaticRoute]:
        """IPv4 StaticRoute configs to upsert"""

    def __init__(
        self,
        *,
        private_connection_id: builtins.str = ...,
        ipv4_static_routes: collections.abc.Iterable[yandex.cloud.cic.v1.private_connection_pb2.PrivateConnection.StaticRoute] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ipv4_static_routes", b"ipv4_static_routes", "private_connection_id", b"private_connection_id"]) -> None: ...

global___UpsertStaticRouteRequest = UpsertStaticRouteRequest

@typing.final
class UpsertStaticRouteMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_connection_id: builtins.str
    """ID of the PrivateConnection resource."""
    def __init__(
        self,
        *,
        private_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_connection_id", b"private_connection_id"]) -> None: ...

global___UpsertStaticRouteMetadata = UpsertStaticRouteMetadata

@typing.final
class RemoveStaticRouteRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CONNECTION_ID_FIELD_NUMBER: builtins.int
    IPV4_STATIC_ROUTES_FIELD_NUMBER: builtins.int
    private_connection_id: builtins.str
    """ID of the PrivateConnection resource."""
    @property
    def ipv4_static_routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cic.v1.private_connection_pb2.PrivateConnection.StaticRoute]:
        """IPv4 StaticRoute configs to remove"""

    def __init__(
        self,
        *,
        private_connection_id: builtins.str = ...,
        ipv4_static_routes: collections.abc.Iterable[yandex.cloud.cic.v1.private_connection_pb2.PrivateConnection.StaticRoute] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ipv4_static_routes", b"ipv4_static_routes", "private_connection_id", b"private_connection_id"]) -> None: ...

global___RemoveStaticRouteRequest = RemoveStaticRouteRequest

@typing.final
class RemoveStaticRouteMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_connection_id: builtins.str
    """ID of the PrivateConnection resource."""
    def __init__(
        self,
        *,
        private_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_connection_id", b"private_connection_id"]) -> None: ...

global___RemoveStaticRouteMetadata = RemoveStaticRouteMetadata

@typing.final
class ListPrivateConnectionOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CONNECTION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    private_connection_id: builtins.str
    """ID of the PrivateConnection resource."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListPrivateConnectionOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests. Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListPrivateConnectionOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        private_connection_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "private_connection_id", b"private_connection_id"]) -> None: ...

global___ListPrivateConnectionOperationsRequest = ListPrivateConnectionOperationsRequest

@typing.final
class ListPrivateConnectionOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListPrivateConnectionOperationsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListPrivateConnectionOperationsRequest.page_token] query parameter
    in the next list request. Subsequent list requests will have their own
    [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of PrivateConnection operations."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListPrivateConnectionOperationsResponse = ListPrivateConnectionOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.clickhouse.v1.cluster_extension_pb2
import yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ClusterExtensionServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.GetClusterExtensionRequest,
        yandex.cloud.mdb.clickhouse.v1.cluster_extension_pb2.ClusterExtension,
    ]

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.ListClusterExtensionsRequest,
        yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.ListClusterExtensionsResponse,
    ]

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.CreateClusterExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.DeleteClusterExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.UpdateClusterExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    SetExtensions: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.SetClusterExtensionsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Set the list of cluster extensions. Not specified extensions will be deleted."""

class ClusterExtensionServiceAsyncStub:
    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.GetClusterExtensionRequest,
        yandex.cloud.mdb.clickhouse.v1.cluster_extension_pb2.ClusterExtension,
    ]

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.ListClusterExtensionsRequest,
        yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.ListClusterExtensionsResponse,
    ]

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.CreateClusterExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.DeleteClusterExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.UpdateClusterExtensionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    SetExtensions: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.SetClusterExtensionsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Set the list of cluster extensions. Not specified extensions will be deleted."""

class ClusterExtensionServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.GetClusterExtensionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.clickhouse.v1.cluster_extension_pb2.ClusterExtension, collections.abc.Awaitable[yandex.cloud.mdb.clickhouse.v1.cluster_extension_pb2.ClusterExtension]]: ...

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.ListClusterExtensionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.ListClusterExtensionsResponse, collections.abc.Awaitable[yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.ListClusterExtensionsResponse]]: ...

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.CreateClusterExtensionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.DeleteClusterExtensionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.UpdateClusterExtensionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

    @abc.abstractmethod
    def SetExtensions(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2.SetClusterExtensionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Set the list of cluster extensions. Not specified extensions will be deleted."""

def add_ClusterExtensionServiceServicer_to_server(servicer: ClusterExtensionServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ResourcePreset(google.protobuf.message.Message):
    """A ResourcePreset resource for describing hardware configuration presets."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CORES_FIELD_NUMBER: builtins.int
    CORE_FRACTION_FIELD_NUMBER: builtins.int
    MEMORY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Human-readable ID of the preset."""
    cores: builtins.int
    """Number of CPU cores for an instance created with the preset."""
    core_fraction: builtins.int
    """Baseline level of CPU performance with the possibility to burst performance above that baseline level.
    This field sets baseline performance for each core.
    """
    memory: builtins.int
    """RAM volume for an instance created with the preset, in bytes."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        cores: builtins.int = ...,
        core_fraction: builtins.int = ...,
        memory: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["core_fraction", b"core_fraction", "cores", b"cores", "id", b"id", "memory", b"memory"]) -> None: ...

global___ResourcePreset = ResourcePreset
